@@ -46,7 +46,7 @@ def get_image_schema():
 @utils.schema_args(get_image_schema, omit=['created_at', 'updated_at', 'file',
                                            'checksum', 'virtual_size', 'size',
                                            'status', 'schema', 'direct_url',
-                                           'locations'])
+                                           'locations', 'self'])
 @utils.arg('--property', metavar="<key=value>", action='append',
            default=[], help=('Arbitrary property to associate with image.'
                              ' May be used multiple times.'))
@@ -90,7 +90,8 @@ def do_image_create(gc, args):
 @utils.schema_args(get_image_schema, omit=['id', 'locations', 'created_at',
                                            'updated_at', 'file', 'checksum',
                                            'virtual_size', 'size', 'status',
-                                           'schema', 'direct_url', 'tags'])
+                                           'schema', 'direct_url', 'tags',
+                                           'self'])
 @utils.arg('--property', metavar="<key=value>", action='append',
            default=[], help=('Arbitrary property to associate with image.'
                              ' May be used multiple times.'))
@@ -142,8 +143,8 @@ def do_image_update(gc, args):
            help='Sort image list in specified directions.')
 @utils.arg('--sort', metavar='<key>[:<direction>]', default=None,
            help=(("Comma-separated list of sort keys and directions in the "
-                  "form of <key>[:<asc|desc>]. Valid keys: %s. OPTIONAL: "
-                  "Default='name:asc'.") % ', '.join(images.SORT_KEY_VALUES)))
+                  "form of <key>[:<asc|desc>]. Valid keys: %s. OPTIONAL."
+                  ) % ', '.join(images.SORT_KEY_VALUES)))
 def do_image_list(gc, args):
     """List images you can access."""
     filter_keys = ['visibility', 'member_status', 'owner', 'checksum', 'tag']
@@ -169,7 +170,8 @@ def do_image_list(gc, args):
     if args.sort is not None:
         kwargs['sort'] = args.sort
     elif not args.sort_dir and not args.sort_key:
-        kwargs['sort'] = 'name:asc'
+        kwargs['sort_key'] = 'name'
+        kwargs['sort_dir'] = 'asc'
 
     columns = ['ID', 'Name']
 
@@ -274,6 +276,10 @@ def do_explain(gc, args):
 def do_image_download(gc, args):
     """Download a specific image."""
     body = gc.images.data(args.id)
+    if body is None:
+        msg = ('Image %s has no data.' % args.id)
+        utils.exit(msg)
+
     if args.progress:
         body = progressbar.VerboseIteratorWrapper(body, len(body))
     if not (sys.stdout.isatty() and args.file is None):
@@ -313,11 +319,11 @@ def do_image_upload(gc, args):
 @utils.arg('id', metavar='<IMAGE_ID>', help='ID of image to delete.')
 def do_image_delete(gc, args):
     """Delete specified image."""
-    image = gc.images.get(args.id)
-    if image and image.status == "deleted":
-        msg = "No image with an ID of '%s' exists." % image.id
+    try:
+        gc.images.delete(args.id)
+    except exc.HTTPNotFound:
+        msg = "No image with an ID of '%s' exists." % args.id
         utils.exit(msg)
-    gc.images.delete(args.id)
 
 
 @utils.arg('image_id', metavar='<IMAGE_ID>',
